@@ -1,4 +1,5 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+# flake8: noqa
 """ Top-level module for ncar-jobqueue. """
 from pkg_resources import DistributionNotFound, get_distribution
 
@@ -7,6 +8,6 @@ from .cluster import NCARCluster
 
 try:
     __version__ = get_distribution(__name__).version
-except DistributionNotFound:
+except DistributionNotFound:  # pragma: no cover
     # package is not installed
-    pass
+    _version__ = '0.0.0'  # pragma: no cover
